@@ -35,15 +35,6 @@ CREATE INDEX ofUserFlag_sTime_idx ON ofUserFlag (startTime ASC);
 CREATE INDEX ofUserFlag_eTime_idx ON ofUserFlag (endTime ASC);
 
 
-CREATE TABLE ofPrivate (
-  username              VARCHAR2(64)    NOT NULL,
-  name                  VARCHAR2(100)   NOT NULL,
-  namespace             VARCHAR2(200)   NOT NULL,
-  privateData           LONG            NOT NULL,
-  CONSTRAINT ofPrivate_pk PRIMARY KEY (username, name, namespace)
-);
-
-
 CREATE TABLE ofOffline (
   username              VARCHAR2(64)    NOT NULL,
   messageID             INTEGER         NOT NULL,
@@ -122,6 +113,7 @@ CREATE TABLE ofProperty (
   name        VARCHAR2(100) NOT NULL,
   propValue   VARCHAR2(4000) NOT NULL,
   encrypted   INTEGER,
+  iv          CHAR(24),
   CONSTRAINT ofProperty_pk PRIMARY KEY (name)
 );
 
@@ -376,8 +368,9 @@ INSERT INTO ofID (idType, id) VALUES (18, 1);
 INSERT INTO ofID (idType, id) VALUES (19, 1);
 INSERT INTO ofID (idType, id) VALUES (23, 1);
 INSERT INTO ofID (idType, id) VALUES (26, 2);
+INSERT INTO ofID (idType, id) VALUES (27, 1);
 
-INSERT INTO ofVersion (name, version) VALUES ('openfire', 26);
+INSERT INTO ofVersion (name, version) VALUES ('openfire', 30);
 
 -- Entry for admin user
 INSERT INTO ofUser (username, plainPassword, name, email, creationDate, modificationDate)
