@@ -35,15 +35,6 @@ CREATE INDEX ofUserFlag_sTime_idx ON ofUserFlag (startTime ASC);
 CREATE INDEX ofUserFlag_eTime_idx ON ofUserFlag (endTime ASC);
 
 
-CREATE TABLE ofPrivate (
-  username              NVARCHAR(64)    NOT NULL,
-  name                  NVARCHAR(100)   NOT NULL,
-  namespace             NVARCHAR(200)   NOT NULL,
-  privateData           TEXT            NOT NULL,
-  CONSTRAINT ofPrivate_pk PRIMARY KEY (username, name, namespace)
-);
-
-
 CREATE TABLE ofOffline (
   username              NVARCHAR(64)    NOT NULL,
   messageID             INTEGER         NOT NULL,
@@ -127,6 +118,7 @@ CREATE TABLE ofProperty (
   name         NVARCHAR(100) NOT NULL,
   propValue    TEXT NOT NULL,
   encrypted    INTEGER,
+  iv           CHAR(24),
   CONSTRAINT ofProperty_pk PRIMARY KEY (name)
 );
 
@@ -382,8 +374,9 @@ INSERT INTO ofID (idType, id) VALUES (18, 1);
 INSERT INTO ofID (idType, id) VALUES (19, 1);
 INSERT INTO ofID (idType, id) VALUES (23, 1);
 INSERT INTO ofID (idType, id) VALUES (26, 2);
+INSERT INTO ofID (idType, id) VALUES (27, 1);
 
-INSERT INTO ofVersion (name, version) VALUES ('openfire', 26);
+INSERT INTO ofVersion (name, version) VALUES ('openfire', 30);
 
 /* Entry for admin user */
 INSERT INTO ofUser (username, plainPassword, name, email, creationDate, modificationDate)
